@@ -1,8 +1,7 @@
 #' Load Session Data
 #'
-#' @description Loads telemetry and general data from the official F1
-#' data stream via the fastf1 python library. Data is available from
-#' 2018 onward.
+#' @description Loads telemetry and general data from the official F1 data stream via
+#' the fastf1 python library. Data is available from 2018 onward.
 #'
 #' The data loaded can optionally be assigned to a R variable, and then interrogated for
 #' session data streams. See the \href{https://docs.fastf1.dev/}{fastf1 documentation}
@@ -11,15 +10,16 @@
 #' If you have trouble with errors mentioning 'fastf1' or 'get_fastf1_version()' read the
 #' 'Setup FastF1 Connection vignette (run \code{vignette('setup_fastf1', 'f1dataR')}).
 #'
+#' Cache directory can be set by setting `option(f1dataR.cache = [cache dir])`,
+#' default is the current working directory.
+#'
 #' @param obj_name name assigned to the loaded session to be referenced later.
 #' Leave as `'session'` unless otherwise required.
 #' @param season number from 2018 to current season. Defaults to current season.
 #' @param round number from 1 to 23 (depending on season selected) and defaults
 #' to most recent. Also accepts race name.
-#' @param session the code for the session to load Options are `'FP1'`, `'FP2'`, `'FP3'`,
-#' `'Q'`, `'S'`, `'SS'` and `'R'`. Default is `'R'`, which refers to Race.
-#' Cache directory can be set by setting `option(f1dataR.cache = [cache dir])`,
-#' default is the current working directory.
+#' @param session the code for the session to load. Options are `'FP1'`, `'FP2'`, `'FP3'`,
+#' `'Q'`, `'S'`, `'SS'`,`'SQ'`, and `'R'`. Default is `'R'`, which refers to Race.
 #' @param log_level Detail of logging from fastf1 to be displayed. Choice of:
 #' `'DEBUG'`, `'INFO'`, `'WARNING'`, `'ERROR'` and `'CRITICAL.'` See
 #' \href{https://docs.fastf1.dev/fastf1.html#configure-logging-verbosity}{fastf1 documentation}.
@@ -47,8 +47,8 @@ load_race_session <- function(obj_name = "session", season = get_current_season(
     # stop(glue::glue('Year must be between 2018 and {current} (or use "current")',
     #                 current = get_current_season()))
   }
-  if (!(session %in% c("FP1", "FP2", "FP3", "Q", "R", "S", "SS"))) {
-    cli::cli_abort('{.var session} must be one of "FP1", "FP2", "FP3", "Q", "SS", "S", or "R"')
+  if (!(session %in% c("FP1", "FP2", "FP3", "Q", "R", "S", "SS", "SQ"))) {
+    cli::cli_abort('{.var session} must be one of "FP1", "FP2", "FP3", "Q", "SQ", "SS", "S", or "R"')
   }
   if (season == "current") {
     season <- get_current_season()
